@@ -140,6 +140,17 @@ class Distribution(pd.Series):
         """
         return self.make_cdf().quantile(ps, **kwargs)
 
+    def credible_interval(self, p):
+        """Credible interval containing the given probability.
+
+        p: float 0-1
+
+        :return: array of two quantities
+        """
+        tail = (1 - p) / 2
+        ps = [tail, 1 - tail]
+        return self.quantile(ps)
+
     def choice(self, *args, **kwargs):
         """Makes a random sample.
 
@@ -159,9 +170,9 @@ class Distribution(pd.Series):
 
         Uses the probabilities as weights unless `weights` is provided.
 
-        This function returns an array containing a sample of the quantities in this Pmf,
-        which is different from Series.sample, which returns a Series with a sample of
-        the rows in the original Series.
+        This function returns an array containing a sample of the
+        quantities in this Pmf, which is different from Series.sample,
+        which returns a Series with a sample of the rows in the original Series.
 
         args: same as Series.sample
         options: same as Series.sample
@@ -172,6 +183,8 @@ class Distribution(pd.Series):
         pmf = self.make_pmf()
         return pmf.sample(*args, **kwargs)
 
+    # TODO: Consider overriding add so it underrides fill_value=0
+
     def add_dist(self, x):
         """Distribution of the sum of values drawn from self and x.
 
@@ -293,6 +306,32 @@ class Distribution(pd.Series):
         pmf = self.make_pmf()
         return pmf.ne_dist(x)
 
+    def max_dist(self, n):
+        """Distribution of the maximum of `n` values from this distribution.
+
+        n: integer
+
+        :return: Distribution, same type as self
+        """
+        cdf = self.make_cdf().max_dist(n)
+        return self.make_same(cdf)
+
+    def min_dist(self, n):
+        """Distribution of the minimum of `n` values from this distribution.
+
+        n: integer
+
+        :return: Distribution, same type as self
+        """
+        cdf = self.make_cdf().min_dist(n)
+        return self.make_same(cdf)
+
+    prob_gt = gt_dist
+    prob_lt = lt_dist
+    prob_ge = ge_dist
+    prob_le = le_dist
+    prob_eq = eq_dist
+    prob_ne = ne_dist
 
 class Pmf(Distribution):
     """Represents a probability Mass Function (PMF)."""
@@ -673,10 +712,9 @@ class Pmf(Distribution):
         :return: Cdf
         """
         normalize = kwargs.pop('normalize', False)
-        cdf = Cdf(self.cumsum(), **kwargs)
 
-        # replace the last value with a numerically better computation
-        cdf.ps[-1] = np.sum(self)
+        cumulative = np.cumsum(self)
+        cdf = Cdf(cumulative, self.index.copy(), **kwargs)
 
         if normalize:
             cdf.normalize()
@@ -711,17 +749,6 @@ class Pmf(Distribution):
         """
         return dist.make_pmf()
 
-    def credible_interval(self, p):
-        """Credible interval containing the given probability.
-
-        p: float 0-1
-
-        :return: array of two quantities
-        """
-        tail = (1 - p) / 2
-        ps = [tail, 1 - tail]
-        return self.quantile(ps)
-
     @staticmethod
     def from_seq(seq, normalize=True, sort=True, ascending=True,
                  dropna=True, na_position='last', **options):
@@ -876,15 +903,7 @@ class Cdf(Distribution):
         #TODO: check for consistent behavior of copy flag for all make_x
         normalize = kwargs.pop('normalize', False)
 
-        # I'm replacing np.ediff1 with pd.Series.diff to be symmetric
-        # with pd.Series.cumsum in make_cdf
-        #ps = self.ps
-        #diff = np.ediff1d(ps, to_begin=ps[0])
-
-        q0 = self.qs[0]
-        p0 = self.ps[0]
-        diff = self.diff()
-        diff[q0] = p0
+        diff = np.diff(self, prepend=0)
         pmf = Pmf(diff, index=self.index.copy(), **kwargs)
         if normalize:
             pmf.normalize()
@@ -954,6 +973,25 @@ class Cdf(Distribution):
         pmf = self.make_pmf()
         return pmf.sample(*args, **kwargs)
 
+    def max_dist(self, n):
+        """Distribution of the maximum of `n` values from this distribution.
+
+        n: integer
+
+        :return: Cdf
+        """
+        ps = self**n
+        return Cdf(ps, self.index.copy())
+
+    def min_dist(self, n):
+        """Distribution of the minimum of `n` values from this distribution.
+
+        n: integer
+
+        :return: Cdf
+        """
+        ps = 1 - (1 - self)**n
+        return Cdf(ps, self.index.copy())
 
 class Surv(Distribution):
     """Represents a survival function (complementary CDF)."""
